@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # pylint: disable=C0103
 
@@ -16,7 +16,7 @@ import multiprocessing
 
 try:
     from pyflakes.checker import Checker
-    from pyflakes.messages import ImportStarUsed
+    from pyflakes.messages import ImportStarUsed, ImportStarUsage
 except ImportError:
     pass
 
@@ -262,7 +262,7 @@ def __syntaxAndPyflakesCheck(filename, codestring, checkFlakes=True,
             line = detail.lineno
             error = detail.msg
             return [{'error': (fn, line, 0, "", error)}]
-        except:         # this catchall is intentional
+        except:         # __IGNORE_WARNING__
             pass
     
     # pyflakes
@@ -275,8 +275,10 @@ def __syntaxAndPyflakesCheck(filename, codestring, checkFlakes=True,
         warnings = Checker(module, filename, withDoctest=True)
         warnings.messages.sort(key=lambda a: a.lineno)
         for warning in warnings.messages:
-            if ignoreStarImportWarnings and \
-                    isinstance(warning, ImportStarUsed):
+            if ignoreStarImportWarnings and (
+                isinstance(warning, ImportStarUsed) or
+                isinstance(warning, ImportStarUsage)
+            ):
                 continue
             
             _fn, lineno, col, message, msg_args = warning.getMessageData()
