@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,7 +12,7 @@ from __future__ import unicode_literals
 import os
 import fnmatch
 
-from PyQt5.QtCore import pyqtSlot, Qt
+from PyQt5.QtCore import pyqtSlot, Qt, QTimer
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QTreeWidgetItem, \
     QApplication, QHeaderView
 
@@ -57,6 +57,8 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.noResults = True
         self.cancelled = False
         self.__lastFileItem = None
+        self.__finished = True
+        self.__errorItem = None
         
         self.__fileList = []
         self.__project = None
@@ -69,6 +71,8 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         try:
             self.syntaxCheckService = e5App().getObject('SyntaxCheckService')
             self.syntaxCheckService.syntaxChecked.connect(self.__processResult)
+            self.syntaxCheckService.batchFinished.connect(self.__batchFinished)
+            self.syntaxCheckService.error.connect(self.__processError)
         except KeyError:
             self.syntaxCheckService = None
         self.filename = None
@@ -80,25 +84,49 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         self.resultList.sortItems(self.resultList.sortColumn(),
                                   self.resultList.header().sortIndicatorOrder()
                                   )
+    
+    def __createErrorItem(self, filename, message):
+        """
+        Private slot to create a new error item in the result list.
         
-    def __createResultItem(self, file, line, index, error, sourcecode,
+        @param filename name of the file
+        @type str
+        @param message error message
+        @type str
+        """
+        if self.__errorItem is None:
+            self.__errorItem = QTreeWidgetItem(self.resultList, [
+                self.tr("Errors")])
+            self.__errorItem.setExpanded(True)
+            self.__errorItem.setForeground(0, Qt.red)
+        
+        msg = "{0} ({1})".format(self.__project.getRelativePath(filename),
+                                 message)
+        if not self.resultList.findItems(msg, Qt.MatchExactly):
+            itm = QTreeWidgetItem(self.__errorItem, [msg])
+            itm.setForeground(0, Qt.red)
+            itm.setFirstColumnSpanned(True)
+        
+    def __createResultItem(self, filename, line, index, error, sourcecode,
                            isWarning=False):
         """
         Private method to create an entry in the result list.
         
-        @param file file name of file (string)
+        @param filename file name of file (string)
         @param line line number of faulty source (integer or string)
         @param index index number of fault (integer)
         @param error error text (string)
         @param sourcecode faulty line of code (string)
         @param isWarning flag indicating a warning message (boolean)
         """
-        if self.__lastFileItem is None:
+        if self.__lastFileItem is None or \
+                self.__lastFileItem.data(0, self.filenameRole) != filename:
             # It's a new file
-            self.__lastFileItem = QTreeWidgetItem(self.resultList, [file])
+            self.__lastFileItem = QTreeWidgetItem(self.resultList, [
+                self.__project.getRelativePath(filename)])
             self.__lastFileItem.setFirstColumnSpanned(True)
             self.__lastFileItem.setExpanded(True)
-            self.__lastFileItem.setData(0, self.filenameRole, file)
+            self.__lastFileItem.setData(0, self.filenameRole, filename)
         
         itm = QTreeWidgetItem(self.__lastFileItem)
         if isWarning:
@@ -108,7 +136,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         itm.setData(0, Qt.DisplayRole, line)
         itm.setData(1, Qt.DisplayRole, error)
         itm.setData(2, Qt.DisplayRole, sourcecode)
-        itm.setData(0, self.filenameRole, file)
+        itm.setData(0, self.filenameRole, filename)
         itm.setData(0, self.lineRole, int(line))
         itm.setData(0, self.indexRole, index)
         itm.setData(0, self.errorRole, error)
@@ -165,6 +193,7 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             else:
                 self.files = [fn]
             
+            self.__errorItem = None
             self.__clearErrors(self.files)
             
             if codestring or len(self.files) > 0:
@@ -175,7 +204,13 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
 
                 # now go through all the files
                 self.progress = 0
-                self.check(codestring)
+                self.files.sort()
+                if codestring or len(self.files) == 1:
+                    self.__batch = False
+                    self.check(codestring)
+                else:
+                    self.__batch = True
+                    self.checkBatch()
     
     def check(self, codestring=''):
         """
@@ -185,6 +220,9 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         @keyparam codestring optional sourcestring (str)
         """
         if self.syntaxCheckService is None or not self.files:
+            self.checkProgressLabel.setPath("")
+            self.checkProgress.setMaximum(1)
+            self.checkProgress.setValue(1)
             self.__finish()
             return
         
@@ -216,8 +254,70 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
                 self.check()
                 return
         
+        self.__finished = False
         self.syntaxCheckService.syntaxCheck(None, self.filename, self.source)
 
+    def checkBatch(self):
+        """
+        Public method to start a style check batch job.
+        
+        The results are reported to the __processResult slot.
+        """
+        self.__lastFileItem = None
+        
+        self.checkProgressLabel.setPath(self.tr("Preparing files..."))
+        progress = 0
+        
+        argumentsList = []
+        for filename in self.files:
+            progress += 1
+            self.checkProgress.setValue(progress)
+            QApplication.processEvents()
+            
+            try:
+                source = Utilities.readEncodedFile(filename)[0]
+                source = Utilities.normalizeCode(source)
+            except (UnicodeError, IOError) as msg:
+                self.noResults = False
+                self.__createResultItem(
+                    self.filename, 1, 0,
+                    self.tr("Error: {0}").format(str(msg))
+                    .rstrip(), "")
+                continue
+            
+            argumentsList.append((filename, source))
+        
+        # reset the progress bar to the checked files
+        self.checkProgress.setValue(self.progress)
+        self.checkProgressLabel.setPath(self.tr("Transferring data..."))
+        QApplication.processEvents()
+        
+        self.__finished = False
+        self.syntaxCheckService.syntaxBatchCheck(argumentsList)
+    
+    def __batchFinished(self):
+        """
+        Private slot handling the completion of a batch job.
+        """
+        self.checkProgressLabel.setPath("")
+        self.checkProgress.setMaximum(1)
+        self.checkProgress.setValue(1)
+        self.__finish()
+    
+    def __processError(self, fn, msg):
+        """
+        Private slot to process an error indication from the service.
+        
+        @param fn filename of the file
+        @type str
+        @param msg error message
+        @type str
+        """
+        self.__createErrorItem(fn, msg)
+        
+        if not self.__batch:
+            self.check()
+    
     def __processResult(self, fn, problems):
         """
         Private slot to display the reported messages.
@@ -228,8 +328,12 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
             (file name, line number, column, codestring (only at syntax
             errors), the message) (dict)
         """
-        # Check if it's the requested file, otherwise ignore signal
-        if fn != self.filename:
+        if self.__finished:
+            return
+        
+        # Check if it's the requested file, otherwise ignore signal if not
+        # in batch mode
+        if not self.__batch and fn != self.filename:
             return
 
         error = problems.get('error')
@@ -240,49 +344,60 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         
         warnings = problems.get('warnings', [])
         if warnings:
-            source = self.source.splitlines()
+            if self.__batch:
+                try:
+                    source = Utilities.readEncodedFile(fn)[0]
+                    source = Utilities.normalizeCode(source)
+                    source = source.splitlines()
+                except (UnicodeError, IOError):
+                    source = ""
+            else:
+                source = self.source.splitlines()
             for _fn, lineno, col, code, msg in warnings:
                 self.noResults = False
-                try:
-                    scr_line = source[lineno - 1].strip()
-                except IndexError:
+                if source:
+                    try:
+                        scr_line = source[lineno - 1].strip()
+                    except IndexError:
+                        scr_line = ""
+                else:
                     scr_line = ""
                 self.__createResultItem(_fn, lineno, col, msg, scr_line, True)
 
         self.progress += 1
         self.checkProgress.setValue(self.progress)
+        self.checkProgressLabel.setPath(fn)
         QApplication.processEvents()
         self.__resort()
 
-        if self.files:
+        if not self.__batch:
             self.check()
-        else:
-            self.checkProgressLabel.setPath("")
-            self.checkProgress.setMaximum(1)
-            self.checkProgress.setValue(1)
-            self.__finish()
         
     def __finish(self):
         """
         Private slot called when the syntax check finished or the user
         pressed the button.
         """
-        self.cancelled = True
-        self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
-        self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
-        self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
-        
-        if self.noResults:
-            QTreeWidgetItem(self.resultList, [self.tr('No issues found.')])
-            QApplication.processEvents()
-            self.showButton.setEnabled(False)
-        else:
-            self.showButton.setEnabled(True)
-        self.resultList.header().resizeSections(QHeaderView.ResizeToContents)
-        self.resultList.header().setStretchLastSection(True)
-        
-        self.checkProgress.setVisible(False)
-        self.checkProgressLabel.setVisible(False)
+        if not self.__finished:
+            self.__finished = True
+            
+            self.cancelled = True
+            self.buttonBox.button(QDialogButtonBox.Close).setEnabled(True)
+            self.buttonBox.button(QDialogButtonBox.Cancel).setEnabled(False)
+            self.buttonBox.button(QDialogButtonBox.Close).setDefault(True)
+            
+            if self.noResults:
+                QTreeWidgetItem(self.resultList, [self.tr('No issues found.')])
+                QApplication.processEvents()
+                self.showButton.setEnabled(False)
+            else:
+                self.showButton.setEnabled(True)
+            self.resultList.header().resizeSections(
+                QHeaderView.ResizeToContents)
+            self.resultList.header().setStretchLastSection(True)
+            
+            self.checkProgress.setVisible(False)
+            self.checkProgressLabel.setVisible(False)
         
     def on_buttonBox_clicked(self, button):
         """
@@ -293,7 +408,11 @@ class SyntaxCheckerDialog(QDialog, Ui_SyntaxCheckerDialog):
         if button == self.buttonBox.button(QDialogButtonBox.Close):
             self.close()
         elif button == self.buttonBox.button(QDialogButtonBox.Cancel):
-            self.__finish()
+            if self.__batch:
+                self.syntaxCheckService.cancelSyntaxBatchCheck()
+                QTimer.singleShot(1000, self.__finish)
+            else:
+                self.__finish()
         elif button == self.showButton:
             self.on_showButton_clicked()
         
