@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -15,7 +15,8 @@ except NameError:
 
 import os
 
-from PyQt5.QtCore import QProcess, QTimer, pyqtSlot, Qt, QCoreApplication
+from PyQt5.QtCore import QProcess, QTimer, pyqtSlot, Qt, QCoreApplication, \
+    QProcessEnvironment
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox, QLineEdit
 
 from E5Gui import E5MessageBox
@@ -23,6 +24,7 @@ from E5Gui import E5MessageBox
 from .Ui_HgDialog import Ui_HgDialog
 
 import Preferences
+import Utilities
 
 
 class HgDialog(QDialog, Ui_HgDialog):
@@ -115,13 +117,16 @@ class HgDialog(QDialog, Ui_HgDialog):
         self.normal = (exitStatus == QProcess.NormalExit) and (exitCode == 0)
         self.__finish()
     
-    def startProcess(self, args, workingDir=None, showArgs=True):
+    def startProcess(self, args, workingDir=None, showArgs=True,
+                     environment={}):
         """
         Public slot used to start the process.
         
         @param args list of arguments for the process (list of strings)
         @keyparam workingDir working directory for the process (string)
         @keyparam showArgs flag indicating to show the arguments (boolean)
+        @keyparam environment dictionary of environment settings to add
+            or change for the git process (dict of string and string)
         @return flag indicating a successful start of the process
         """
         self.errorGroup.hide()
@@ -130,8 +135,8 @@ class HgDialog(QDialog, Ui_HgDialog):
         
         self.__hasAddOrDelete = False
         if args[0] in ["fetch", "qpush", "qpop", "qgoto", "rebase",
-                       "transplant", "update", "import", "revert",
-                       "graft", "shelve", "unshelve"] or \
+                       "update", "import", "revert", "graft", "shelve",
+                       "unshelve", "strip", "histedit"] or \
            (args[0] in ["pull", "unbundle"] and
                 ("--update" in args[1:] or "--rebase" in args[1:])):
             self.__updateCommand = True
@@ -144,6 +149,11 @@ class HgDialog(QDialog, Ui_HgDialog):
         
         if self.__hgClient is None:
             self.proc = QProcess()
+            if environment:
+                env = QProcessEnvironment.systemEnvironment()
+                for key, value in environment.items():
+                    env.insert(key, value)
+                self.proc.setProcessEnvironment(env)
             
             self.proc.finished.connect(self.__procFinished)
             self.proc.readyReadStandardOutput.connect(self.__readStdout)
@@ -221,7 +231,7 @@ class HgDialog(QDialog, Ui_HgDialog):
         
         @param out output to be shown (string)
         """
-        self.resultbox.insertPlainText(out)
+        self.resultbox.insertPlainText(Utilities.filterAnsiSequences(out))
         self.resultbox.ensureCursorVisible()
         
         # check for a changed project file
@@ -253,7 +263,7 @@ class HgDialog(QDialog, Ui_HgDialog):
         @param out error to be shown (string)
         """
         self.errorGroup.show()
-        self.errors.insertPlainText(out)
+        self.errors.insertPlainText(Utilities.filterAnsiSequences(out))
         self.errors.ensureCursorVisible()
         
         QCoreApplication.processEvents()
