@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -251,7 +251,7 @@ class Subversion(VersionControl):
                     cwdIsPpath = False
                 shutil.rmtree(project.ppath, True)
                 os.rename(tmpProjectDir, project.ppath)
-                project.pdata["VCS"] = ['None']
+                project.pdata["VCS"] = 'None'
                 project.vcs = None
                 project.setDirty(True)
                 project.saveProject()
