@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -25,6 +25,8 @@ from .QsciScintillaCompat import QsciScintillaCompat
 
 import Preferences
 
+import Utilities
+
 import UI.PixmapCache
 
 from Debugger.DebugClientCapabilities import HasCompleter
@@ -176,6 +178,9 @@ class Shell(QsciScintillaCompat):
         self.maxHistoryEntries = Preferences.getShell("MaxHistoryEntries")
         self.history = []
         self.histidx = -1
+        # remove obsolete shell histories (Python and Ruby)
+        for clientType in ["Python", "Ruby"]:
+            Preferences.Prefs.settings.remove("Shell/Histories/" + clientType)
         
         self.clientType = ''
         
@@ -300,8 +305,8 @@ class Shell(QsciScintillaCompat):
         """
         Public method to shutdown the shell.
         """
-        for key in list(self.historyLists.keys()):
-            self.saveHistory(key)
+        for clientType in self.historyLists:
+            self.saveHistory(clientType)
         
     def __bindLexer(self, language='Python3'):
         """
@@ -576,7 +581,12 @@ class Shell(QsciScintillaCompat):
         """
         Private slot to clear the current history.
         """
-        self.history = []
+        if self.clientType:
+            self.historyLists[self.clientType] = []
+            self.history = self.historyLists[self.clientType]
+        else:
+            self.history = []
+        self.histidx = -1
         
     def __selectHistory(self):
         """
@@ -603,6 +613,18 @@ class Shell(QsciScintillaCompat):
             self.history = self.historyLists[self.clientType]
             self.histidx = -1
         
+    def clearAllHistories(self):
+        """
+        Public method to clear all available histories and sync them.
+        """
+        Preferences.Prefs.settings.beginGroup("Shell/Histories")
+        for clientType in Preferences.Prefs.settings.childKeys():
+            self.historyLists[clientType] = []
+            self.saveHistory(clientType)
+        Preferences.Prefs.settings.endGroup()
+        
+        self.__clearHistory()
+        
     def getClientType(self):
         """
         Public slot to get the clients type.
@@ -675,7 +697,7 @@ class Shell(QsciScintillaCompat):
         self .__clientError()
         
         if Preferences.getDebugger("ShowExceptionInShell"):
-            if exceptionType is not None:
+            if exceptionType:
                 if stackTrace:
                     self.__write(
                         self.tr('Exception "{0}"\n{1}\nFile: {2}, Line: {3}\n')
@@ -765,7 +787,7 @@ class Shell(QsciScintillaCompat):
         """
         line, col = self.__getEndPos()
         self.setCursorPosition(line, col)
-        self.insert(s)
+        self.insert(Utilities.filterAnsiSequences(s))
         self.prline, self.prcol = self.getCursorPosition()
         self.ensureCursorVisible()
         self.ensureLineVisible(self.prline)
@@ -897,7 +919,7 @@ class Shell(QsciScintillaCompat):
         @param s text to be inserted (string)
         """
         line, col = self.getCursorPosition()
-        self.insertAt(s, line, col)
+        self.insertAt(Utilities.filterAnsiSequences(s), line, col)
         self.setCursorPosition(line, col + len(s))
         
     def __insertTextAtEnd(self, s):
@@ -908,7 +930,7 @@ class Shell(QsciScintillaCompat):
         """
         line, col = self.__getEndPos()
         self.setCursorPosition(line, col)
-        self.insert(s)
+        self.insert(Utilities.filterAnsiSequences(s))
         self.prline, _ = self.getCursorPosition()
         
     def __insertTextNoEcho(self, s):
@@ -1429,7 +1451,7 @@ class Shell(QsciScintillaCompat):
             if not cmd:
                 cmd = ''
             else:
-                cmd = cmd.replace(self.prompt, "")
+                cmd = cmd[len(self.prompt):]
             self.dbs.remoteRawInput(cmd)
         
     def __useHistory(self):
@@ -1742,6 +1764,7 @@ class Shell(QsciScintillaCompat):
         
         @param txt text to be inserted (string)
         """
+        txt = Utilities.filterAnsiSequences(txt)
         length = len(txt)
         line, col = self.getCursorPosition()
         self.insertAt(txt, line, col)
