@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,8 +16,8 @@ from __future__ import unicode_literals
 import sys
 
 # generate list of arguments to be remembered for a restart
-restartArgsList = ["--nosplash", "--plugin", "--debug", "--config", "--pyqt4"
-                   "--settings"]
+restartArgsList = ["--no-splash", "--plugin", "--debug", "--config",
+                   "--pyqt4", "--settings", "--disable-crash"]
 restartArgs = [arg for arg in sys.argv[1:]
                if arg.split("=", 1)[0] in restartArgsList]
 
@@ -113,10 +113,16 @@ def handleSingleApplication(ddindex):
     client = E5SingleApplicationClient()
     res = client.connect()
     if res > 0:
-        if "--nosplash" in sys.argv and sys.argv.index("--nosplash") < ddindex:
-            del sys.argv[sys.argv.index("--nosplash")]
-        if "--noopen" in sys.argv and sys.argv.index("--noopen") < ddindex:
-            del sys.argv[sys.argv.index("--noopen")]
+        if "--no-splash" in sys.argv and \
+                sys.argv.index("--no-splash") < ddindex:
+            del sys.argv[sys.argv.index("--no-splash")]
+        if "--no-open" in sys.argv and sys.argv.index("--no-open") < ddindex:
+            del sys.argv[sys.argv.index("--no-open")]
+        if "--no-crash" in sys.argv and sys.argv.index("--no-crash") < ddindex:
+            del sys.argv[sys.argv.index("--no-crash")]
+        if "--disable-crash" in sys.argv and \
+                sys.argv.index("--disable-crash") < ddindex:
+            del sys.argv[sys.argv.index("--disable-crash")]
         if "--debug" in sys.argv and sys.argv.index("--debug") < ddindex:
             del sys.argv[sys.argv.index("--debug")]
         for arg in sys.argv:
@@ -127,7 +133,7 @@ def handleSingleApplication(ddindex):
             client.processArgs(sys.argv[1:])
         sys.exit(0)
     elif res < 0:
-        print("eric6: {0}".format(client.errstr()))
+        print("eric6: {0}".format(client.errstr()))     # __IGNORE_WARNING__
         sys.exit(res)
 
 
@@ -188,7 +194,7 @@ def excepthook(excType, excValue, tracebackobj):
             msg = msg.encode(sys.stdout.encoding, 'replace')
             versionInfo = versionInfo.encode(sys.stdout.encoding, 'replace')
         warning = notice + msg + versionInfo
-        print(warning)
+        print(warning)                          # __IGNORE_WARNING__
     else:
         warning = notice + msg + versionInfo
         # Escape &<> otherwise it's not visible in the error dialog
@@ -234,9 +240,11 @@ def main():
         ("--config=configDir",
          "use the given directory as the one containing the config files"),
         ("--debug", "activate debugging output to the console"),
-        ("--nosplash", "don't show the splash screen"),
-        ("--noopen",
+        ("--no-splash", "don't show the splash screen"),
+        ("--no-open",
          "don't open anything at startup except that given in command"),
+        ("--no-crash", "don't check for a crash session file on startup"),
+        ("--disable-crash", "disable the support for crash sessions"),
         ("--plugin=plugin-file",
          "load the given plugin file (plugin development)"),
         ("--pyqt4",
@@ -279,8 +287,8 @@ def main():
 
     # generate and show a splash window, if not suppressed
     from UI.SplashScreen import SplashScreen, NoneSplashScreen
-    if "--nosplash" in sys.argv and sys.argv.index("--nosplash") < ddindex:
-        del sys.argv[sys.argv.index("--nosplash")]
+    if "--no-splash" in sys.argv and sys.argv.index("--no-splash") < ddindex:
+        del sys.argv[sys.argv.index("--no-splash")]
         splash = NoneSplashScreen()
     elif not Preferences.getUI("ShowSplash"):
         splash = NoneSplashScreen()
@@ -301,9 +309,18 @@ def main():
     
     pluginFile = None
     noopen = False
-    if "--noopen" in sys.argv and sys.argv.index("--noopen") < ddindex:
-        del sys.argv[sys.argv.index("--noopen")]
+    nocrash = False
+    disablecrash=False
+    if "--no-open" in sys.argv and sys.argv.index("--no-open") < ddindex:
+        del sys.argv[sys.argv.index("--no-open")]
         noopen = True
+    if "--no-crash" in sys.argv and sys.argv.index("--no-crash") < ddindex:
+        del sys.argv[sys.argv.index("--no-crash")]
+        nocrash = True
+    if "--disable-crash" in sys.argv and \
+            sys.argv.index("--disable-crash") < ddindex:
+        del sys.argv[sys.argv.index("--disable-crash")]
+        disablecrash = True
     for arg in sys.argv:
         if arg.startswith("--plugin=") and sys.argv.index(arg) < ddindex:
             import Utilities
@@ -320,12 +337,12 @@ def main():
         args = sys.argv[1:]
     
     # get the Qt4 translations directory
-    qt4TransDir = Preferences.getQt4TranslationsDir()
-    if not qt4TransDir:
-        qt4TransDir = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
+    qtTransDir = Preferences.getQtTranslationsDir()
+    if not qtTransDir:
+        qtTransDir = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
     
     # Load translation files and install them
-    loc = Startup.loadTranslators(qt4TransDir, app, ("qscintilla",))
+    loc = Startup.loadTranslators(qtTransDir, app, ("qscintilla",))
     
     # Initialize SSL stuff
     from E5Network.E5SslUtilities import initSSL
@@ -338,8 +355,8 @@ def main():
 
     splash.showMessage(
         QCoreApplication.translate("eric6", "Generating Main Window..."))
-    mainWindow = UserInterface(app, loc, splash, pluginFile, noopen,
-                               restartArgs)
+    mainWindow = UserInterface(app, loc, splash, pluginFile, noopen, nocrash,
+                               disablecrash, restartArgs)
     app.lastWindowClosed.connect(app.quit)
     mainWindow.show()
     
